.. _tutor_trackapps:

TrackApps
=========

TrackApps extension provides interface to bugtracking and test management applications.

Following applications are supported.

* Quality Center - bugtracking, test management
* Bugzilla - bugtracking
* Mantis - bugtracking
* Trac - bugtracking
* Jira - bugtracking
* TestLink - test management

.. toctree::
   :maxdepth: 1
   
   tut1_qc
   tut2_bugzilla
   tut3_mantis
   tut4_trac
   tut5_jira
   tut6_testlink

